@@ -7,7 +7,17 @@ import json
 from functools import cmp_to_key
 from statsmodels.stats.multicomp import pairwise_tukeyhsd
 
-def multcompCatplot(**kwargs):
+def multcompCatplot(letterSize=matplotlib.rcParams["font.size"],
+                    pointStyle=None,
+                    printTest=False,
+                    custom_color=None,
+                    addPoints=False,
+                    boxColor="#f0f0f0",
+                    pointArgs={"linewidth":1},
+                    pointSize=None,
+                    coloredObject=None,
+                    separateCld=False,
+                    **kwargs):
     if "kind" not in kwargs:
         kwargs["kind"] = "box"
     if kwargs["kind"] not in ("box","violin"):
@@ -15,22 +25,10 @@ def multcompCatplot(**kwargs):
     value = kwargs["y"];
     kwargs["data"]  = kwargs["data"].dropna();
     facet_vars = ["row","col","x","hue"]
-    if "letterSize" not in kwargs:
-        kwargs["letterSize"] = matplotlib.rcParams["font.size"]
-    letterSize = kwargs["letterSize"]
-    del kwargs["letterSize"]
-    if "pointStyle" not in kwargs:
-        kwargs["pointStyle"] = None
-    pointStyle = kwargs["pointStyle"]
-    del kwargs["pointStyle"]
-    if "separateCld" not in kwargs:
-        kwargs["separateCld"] = False
-    separateCld = kwargs["separateCld"]
     if separateCld:
         filterFacet_vars = ["row","col"]
     else:
         filterFacet_vars = []
-    del kwargs["separateCld"]
     facet_orders = {}
     facets = []
     for var in facet_vars:
@@ -54,6 +52,9 @@ def multcompCatplot(**kwargs):
                             groups=tkf['comb'],
                             alpha=0.05)
         tukey_df = pd.DataFrame(data=tukey._results_table.data[1:], columns=tukey._results_table.data[0])
+        if printTest:
+            print(filterVal)
+            print(tukey_df[['group1', 'group2','p-adj']])
         letters_df = makeletters(tukey_df,alpha=0.05,sortingOrder=median_df.index.tolist())
         letters.extend([[x[1],x[2]] for x in letters_df.reset_index().values.tolist()])
 
@@ -68,31 +69,17 @@ def multcompCatplot(**kwargs):
             return 1
         return 0
     letters.sort(key=cmp_to_key(sortCustom))
-    custom_color = None
-    if "custom_color" in kwargs:
-        custom_color = kwargs["custom_color"]
-        del kwargs["custom_color"]
-    
-    if "addPoints" in kwargs:
-        coloredObject = "points"
-        addPoints = kwargs["addPoints"]
-        if addPoints and "hue" in kwargs:
+    if addPoints and "hue" in kwargs:
             quit("Cannot use hue together with points")
-        del kwargs["addPoints"]
-    else:
+
+    if addPoints and not coloredObject:
+        coloredObject = "points"
+    elif not coloredObject:
         coloredObject = "box"
-        addPoints = False
-    if "coloredObject" in kwargs:
-        coloredObject = kwargs["coloredObject"]
-        del kwargs["coloredObject"]
-    if "pointArgs" in kwargs:
-        pointArgs = kwargs["pointArgs"]
-        del kwargs["pointArgs"]
-    elif "pointSize" in kwargs:
-        pointArgs = {"size": kwargs["pointSize"], "linewidth":1}
-        del kwargs["pointSize"]
-    else:
-        pointArgs = {"linewidth":1}
+
+    if pointSize and "size" not in pointArgs:
+        pointArgs["size"] = pointSize
+
     g = sns.catplot(**kwargs)
     if addPoints:
         g.map_dataframe(pointStyleStripplot, pointStyle=pointStyle, coloredObject=coloredObject, pointArgs=pointArgs, x=kwargs["x"], y=kwargs["y"], hue=custom_color[0], palette=custom_color[1])
@@ -106,7 +93,7 @@ def multcompCatplot(**kwargs):
                 if coloredObject == "box" and custom_color and (custom_color[0] in data) and (data[custom_color[0]] in custom_color[1]):
                     p.set_facecolor(custom_color[1][data[custom_color[0]]])
                 else:
-                    p.set_facecolor("white")
+                    p.set_facecolor(boxColor)
                 ax.text(bbox.xmax, bbox.ymax, annotation, ha = 'right', va = 'bottom', size=letterSize)
             elif type(p) == matplotlib.collections.PolyCollection:
                 bbox = p.get_paths()[0].get_extents()
@@ -115,7 +102,7 @@ def multcompCatplot(**kwargs):
                 if coloredObject == "box" and custom_color and (custom_color[0] in data) and (data[custom_color[0]] in custom_color[1]):
                     p.set_facecolor(custom_color[1][data[custom_color[0]]])
                 else:
-                    p.set_facecolor("white")
+                    p.set_facecolor(boxColor)
                 ax.text((bbox.xmax+bbox.xmin)/2, bbox.ymax, annotation, ha = 'center', va = 'bottom', size=letterSize)
     return g
 
@@ -128,11 +115,7 @@ colors = {
     "xnd1-5":"#0072b2"
 }
 
-def pointStyleStripplot(*args, **kwargs):
-    pointStyle = kwargs["pointStyle"]
-    coloredObject = kwargs["coloredObject"]
-    del kwargs["coloredObject"]
-    del kwargs["pointStyle"]
+def pointStyleStripplot(*args, pointStyle=None, data=None, coloredObject=None, **kwargs):
     if coloredObject == "box":
         del kwargs["hue"]
         del kwargs["palette"]
@@ -145,14 +128,11 @@ def pointStyleStripplot(*args, **kwargs):
     if not pointStyle:
         sns.stripplot(*args,**kwargs)
         return
-    xdata = kwargs["data"]
-    types = xdata[pointStyle].unique().tolist()
-    del kwargs["data"]
-    print(types)
+    types = data[pointStyle].unique().tolist()
     markers = ["o",'s','^','P','*','v',  '<', '>', 'p',  'h', 'H', 'D', 'd',  'X','8']
     i = 0
     for subtype in types:
-        kwargs["data"] = xdata[xdata[pointStyle] == subtype]
+        kwargs["data"] = data[data[pointStyle] == subtype]
         kwargs["marker"] = markers[i%len(markers)]
         sns.stripplot(*args,**kwargs)
         i+=1
